pub struct AlertAggregation {
pub limit: i64,
pub key: String,
}Fields
limit: i64Time at witch the Alert system must create a new case
key: StringKey to be used in the aggregation of alerts as to join multiple alerts into one