#[non_exhaustive]pub enum SiemMessage {
Command(SiemCommandHeader, SiemCommandCall),
Response(SiemCommandHeader, SiemCommandResponse),
Log(SiemLog),
Notification(Notification),
Dataset(SiemDataset),
Alert(SiemAlert),
Task(SiemCommandHeader, SiemTask),
TaskResult(SiemCommandHeader, SiemTaskResult),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Command(SiemCommandHeader, SiemCommandCall)
Execute a command in the component
Response(SiemCommandHeader, SiemCommandResponse)
Response to a function call, first element is the ID of the Response
Log(SiemLog)
Process a log
Notification(Notification)
Local logging system. First element is the ID of the component, to be able to route messages
Dataset(SiemDataset)
Dataset updated, this is the last state of it.
Alert(SiemAlert)
Alerting
Task(SiemCommandHeader, SiemTask)
TaskResult(SiemCommandHeader, SiemTaskResult)