pub enum LogParsingError {
NoValidParser(SiemLog),
ParserError(SiemLog, String),
NotImplemented(SiemLog),
FormatError(SiemLog, String),
Discard,
}Expand description
Error at parsing a log
Variants
NoValidParser(SiemLog)
The parser can’t be used with this log
ParserError(SiemLog, String)
The log is for this parser but there is a bug in the code
NotImplemented(SiemLog)
The log is for this parser but the submodule has not been implemented.
FormatError(SiemLog, String)
The log has change format the parser cant process it.
Discard
Log was discarded. It does not have utility or there are storage limitations.