Module task

Module task 

Structs

SiemTask
Enqueued task with data. If the Task has finished then the result has Some data. This data can be a Ok with the output (not the data) or the error. The ID is to get the Task result
SiemTaskResult
TaskDefinition

Enums

SiemTaskData
SiemTaskType
TaskFireMode

Traits

TaskBuilder2

Type Aliases

TaskBuilder