pub fn initialize_component_logger(msngr: KernelMessager)Expand description
Initializes the channel to communicate with the Kernel for the current thread/component.
pub fn initialize_component_logger(msngr: KernelMessager)Initializes the channel to communicate with the Kernel for the current thread/component.