Module task
usiem
0.7.0
Module task
Module Items
Structs
Enums
Traits
Type Aliases
In usiem::
components
usiem
::
components
Module
task
Structs

Siem
Task
Enqueued task with data. If the Task has finished then the result has Some data. This data can be a Ok with the output (not the data) or the error. The ID is to get the Task result
Siem
Task
Result
Task
Definition
Enums

Siem
Task
Data
Siem
Task
Type
Task
Fire
Mode
Traits

Task
Builder2
Type Aliases

Task
Builder